<?php
/**
 * Perfect Checkout - Admin Plugin Screen.
 *
 * @author  Sébastien Dumont
 * @package Perfect Checkout\Admin\Plugin Screen
 * @since   1.0.7
 */

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if ( ! class_exists( 'Perfect_Checkout_Admin_Plugin_Screen' ) ) {

	class Perfect_Checkout_Admin_Plugin_Screen {

		/**
		 * Constructor
		 *
		 * @access public
		 */
		public function __construct() {
			// Includes the deactivation modal.
			add_action( 'wp_ajax_perfectcheckout_feedback', array( $this, 'ajax_perfect_checkout_feedback_modal' ) );
			add_action( 'admin_footer', array( $this, 'deactivation_modal' ), 9999 );
		} // END __construct()

		/**
		 * Sends feedback details from deactivation modal via email.
		 *
		 * @access public
		 */
		public function ajax_perfect_checkout_feedback_modal() {
			$reason  = isset( $_POST['fb_reason'] ) ? trim( sanitize_text_field( wp_unslash( $_POST['fb_reason'] ) ) ) : ''; // phpcs:ignore WordPress.Security.NonceVerification.Missing
			$details = isset( $_POST['fb_details'] ) ? sanitize_text_field( wp_unslash( $_POST['fb_details'] ) ) : ''; // phpcs:ignore WordPress.Security.NonceVerification.Missing

			$user_id      = get_current_user_id();
			$userdata     = get_userdata( $user_id );
			$merchant_url = get_site_url();

			$from    = get_option( 'admin_email' );
			$send_to = sanitize_email( 'support@perfectcheckout.com' );
			$subject = 'Merchant Deactivation: ' . $merchant_url . ' Reason: ' . $reason;
			$message = get_option( 'perfectcheckout_license' );

			$headers = array(
				'Content-Type: text/html; charset=UTF-8',
				'From: ' . $userdata->display_name . ' <' . $from . '>',
			);

			$email = wp_mail( $send_to, $subject, $message, $headers );

			if ( $email ) {
				return true;
			}

			return false;
		} // END ajax_perfect_checkout_feedback_modal()

		/**
		 * Includes the deactivation modal.
		 *
		 * @access public
		 */
		public function deactivation_modal() {
			// If the current user can not install plugins then return nothing!
			if ( ! Perfect_Checkout_Helpers::user_has_capabilities() ) {
				return false;
			}

			// Notice should only show on a Perfect Checkout page.
			if ( ! Perfect_Checkout_Helpers::is_perfect_checkout_admin_page() ) {
				return false;
			}

			include_once dirname( PERFECTCHECKOUT_FILE ) . '/includes/admin/views/html-modal-deactivation.php';
		} // END deactivation_modal()

	} // END class

} // END if class exists

return new Perfect_Checkout_Admin_Plugin_Screen();
