<?php
/**
 * Perfect Checkout Settings Page
 *
 * @author  Sébastien Dumont
 * @package Perfect Checkout\Admin\Settings
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

if ( ! class_exists( 'Perfect_Checkout_Settings_Page' ) ) {

	abstract class Perfect_Checkout_Settings_Page {

		/**
		 * Setting page id.
		 *
		 * @access protected
		 * @var    string $id
		 */
		protected $id = '';

		/**
		 * Setting page label.
		 *
		 * @access protected
		 * @var    string $label
		 */
		protected $label = '';

		/**
		 * Constructor.
		 *
		 * @access public
		 */
		public function __construct() {
			add_action( 'perfect_checkout_settings_' . $this->id, array( $this, 'output' ), 10 );
			add_action( 'perfect_checkout_settings_save_' . $this->id, array( $this, 'save' ) );
		}

		/**
		 * Get settings page ID.
		 *
		 * @access public
		 * @return string
		 */
		public function get_id() {
			return $this->id;
		} // END get_id()

		/**
		 * Get settings page label.
		 *
		 * @access public
		 * @return string
		 */
		public function get_label() {
			return $this->label;
		} // END get_label()

		/**
		 * Add this page to settings.
		 *
		 * @access public
		 * @param  array $pages
		 * @return array $pages
		 */
		public function add_settings_page( $pages ) {
			$pages[ $this->id ] = $this->label;

			return $pages;
		} // END add_settings_page()

		/**
		 * Add this settings page to plugin menu.
		 *
		 * @access public
		 * @param  array $pages
		 * @return array $pages
		 */
		public function add_menu_page( $pages ) {
			$pages[ $this->id ] = $this->label;

			return $pages;
		} // END add_menu_page()

		/**
		 * Get settings array
		 *
		 * @access public
		 * @return array
		 */
		public function get_settings() {
			return array();
		} // END get_settings()

		/**
		 * Output the settings.
		 *
		 * @access public
		 */
		public function output() {
			$settings = $this->get_settings();

			Perfect_Checkout_Admin_Settings::output_fields( $settings );
		} // END output()

		/**
		 * Save settings.
		 *
		 * @access public
		 */
		public function save() {
			$settings = $this->get_settings();

			Perfect_Checkout_Admin_Settings::save_fields( $settings );
		} // END save()

	} // END class

} // END if class exists.
