<?php
/**
 * Admin View: WooCommerce not installed or activated notice.
 *
 * @author  Sébastien Dumont
 * @since   1.6.0
 * @package Perfect Checkout\Admin\Views
 */

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}
?>
<div class="notice notice-warning">
	<p>
		<?php
		echo sprintf(
			/* translators: 1: Perfect Checkout, 2: WooCommerce */
			esc_html__( '%1$s requires %2$s to be installed and activated.', 'perfect-checkout' ),
			'Perfect Checkout',
			'WooCommerce'
		);
		?>
	</p>

	<p>
		<?php
		if ( ! is_plugin_active( 'woocommerce/woocommerce.php' ) && file_exists( WP_PLUGIN_DIR . '/woocommerce/woocommerce.php' ) ) :

			if ( current_user_can( 'activate_plugin', 'woocommerce/woocommerce.php' ) ) :

				echo sprintf( '<a href="%1$s" class="button button-primary" aria-label="%2$s">%2$s</a>', esc_url( wp_nonce_url( self_admin_url( 'plugins.php?action=activate&plugin=woocommerce/woocommerce.php&plugin_status=active' ), 'activate-plugin_woocommerce/woocommerce.php' ) ), esc_html__( 'Activate WooCommerce', 'perfect-checkout' ) );

			else :

				echo esc_html__( 'As you do not have permission to activate a plugin. Please ask a site administrator to activate WooCommerce for you.', 'perfect-checkout' );

			endif;

		else :

			if ( current_user_can( 'install_plugins' ) ) {
				$url = wp_nonce_url( self_admin_url( 'update.php?action=install-plugin&plugin=woocommerce' ), 'install-plugin_woocommerce' );
			} else {
				$url = 'https://wordpress.org/plugins/woocommerce/';
			}

			echo '<a href="' . esc_url( $url ) . '" class="button button-primary" aria-label="' . esc_html__( 'Install WooCommerce', 'perfect-checkout' ) . '">' . esc_html__( 'Install WooCommerce', 'perfect-checkout' ) . '</a>';

		endif;
		?>
	</p>
</div>
