<?php
/**
 * Perfect Checkout logger.
 *
 * Handles logging errors.
 *
 * @author  Sébastien Dumont
 * @package Perfect Checkout\Classes
 * @since   1.5.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Perfect Checkout logger class.
 *
 * @package Perfect Checkout/Logger
 */
class Perfect_Checkout_Logger {

	/**
	 * Log Handler Interface.
	 *
	 * @access public
	 * @static
	 * @var object $logger Log Handler Interface.
	 */
	public static $logger;

	/**
	 * Log issues or errors within Perfect Checkout.
	 *
	 * @access public
	 * @static
	 * @since  1.5.0
	 * @param  string $message The message of the log.
	 * @param  string $type    The type of log to record.
	 */
	public static function log( $message, $type ) {
		if ( ! class_exists( 'WC_Logger' ) ) {
			return;
		}

		if ( defined( 'WP_DEBUG' ) && WP_DEBUG ) {
			if ( empty( self::$logger ) ) {
				self::$logger = wc_get_logger();
			}

			$log_entry = "\n" . '====Perfect Checkout Version: ' . PERFECTCHECKOUT_VERSION . '====' . "\n";
			$context   = array( 'source' => 'perfect-checkout' );

			$log_time = date_i18n( get_option( 'date_format' ), current_time( 'timestamp' ) ) . ' @ ' . date_i18n( get_option( 'time_format' ), current_time( 'timestamp' ) ); // phpcs:ignore WordPress.DateTime.CurrentTimeTimestamp.Requested

			$log_entry .= '====Start Log ' . $log_time . '====' . "\n" . $message . "\n";
			$log_entry .= '====End Log====' . "\n\n";

			switch ( $type ) {
				// Interesting events.
				case 'info':
					self::$logger->info( $log_entry, $context );
					break;
				// Normal but significant events.
				case 'notice':
					self::$logger->notice( $log_entry, $context );
					break;
				// Exceptional occurrences that are not errors.
				case 'warning':
					self::$logger->warning( $log_entry, $context );
					break;
				// Runtime errors that do not require immediate.
				case 'error':
					self::$logger->error( $log_entry, $context );
					break;
				// Critical conditions.
				case 'critical':
					self::$logger->critical( $log_entry, $context );
					break;
				// Action must be taken immediately.
				case 'alert':
					self::$logger->alert( $log_entry, $context );
					break;
				// System is unusable.
				case 'emergency':
					self::$logger->emergency( $log_entry, $context );
					break;
				// Detailed debug information.
				case 'debug':
				default:
					self::$logger->debug( $log_entry, $context );
					break;
			}
		}
	} // END log()

} // END class
