<?php
/**
 * Perfect Checkout Updates
 *
 * Functions for updating data, used by the background updater.
 *
 * @author  Sébastien Dumont
 * @package Perfect Checkout\Functions
 * @since   1.5.0
 * @license GPL-2.0+
 */

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Update options for version 1.5.0
 */
function perfectcheckout_update_150_options() {
	// Restore native cart and checkout pages.
	// Delete old options after.
	$cart_page_id     = get_option( 'perfectcheckout_wc_cart_page_id', true );
	$checkout_page_id = get_option( 'perfectcheckout_wc_checkout_page_id', true );

	if ( $cart_page_id > 0 ) {
		$cart_page = get_post( $cart_page_id, 'ARRAY_A' );

		// If the page is not published the re-publish it.
		if ( 'publish' !== $cart_page['post_status'] ) {
			$cart_page['post_status'] = 'publish';
			wp_update_post( $cart_page );

			// Set back the native cart page.
			update_option( 'woocommerce_cart_page_id', $cart_page_id );
		}

		delete_option( 'perfectcheckout_wc_cart_page_id' );
	}

	if ( $checkout_page_id > 0 ) {
		$checkout_page = get_post( $checkout_page_id, 'ARRAY_A' );

		// If the page is not published the re-publish it.
		if ( 'publish' !== $checkout_page['post_status'] ) {
			$checkout_page['post_status'] = 'publish';
			wp_update_post( $checkout_page );

			// Set back the native checkout page.
			update_option( 'woocommerce_checkout_page_id', $checkout_page_id );
		}

		delete_option( 'perfectcheckout_wc_checkout_page_id' );
	}

	// Set Perfect Checkout page ID.
	$pc_page_id = get_page_by_path( 'perfect-checkout', OBJECT, 'page' );
	add_option( 'perfectcheckout_page_id', $pc_page_id );

	// Set Perfect Checkout as active.
	add_option( 'perfectcheckout_set_active', 'yes' );
}
