<?php
/**
 * Template Name: Perfect Checkout.
 *
 * Loads PerfectCheckout iframe.
 *
 * @package Perfect Checkout\Templates
 * @version 1.6.10
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

// Gets unique cart key.
$cart_key = WC()->session->get_customer_unique_id();

// Return requested cart key if set.
$cart_key = ! empty( $_REQUEST['pc-key'] ) ? trim( sanitize_text_field( wp_unslash( $_REQUEST['pc-key'] ) ) ) : $cart_key;

// Return cart key if set by query variable.
$cart_key = isset( $wp->query_vars['cs'] ) ? trim( sanitize_text_field( wp_unslash( $wp->query_vars['cs'] ) ) ) : $cart_key;

$pc_license     = get_option( 'perfectcheckout_license' );
$ga_tracking_id = get_option( 'perfectcheckout_google_analytics' );

// API URL.
$api_url = PerfectCheckout::get_api_url();

// Passes arguments for iFrame.
$frame_url = add_query_arg( array(
	'pc_version' => PERFECTCHECKOUT_VERSION,
	'lang'       => get_locale(),
	'text_dir'   => function_exists( 'is_rtl' ) && is_rtl() ? 'rtl' : 'ltr',
	'id'         => $pc_license, // Perfect Checkout account ID.
	'ck'         => $cart_key, // Cart key.
	'site_url'   => home_url(), // Site URL.
), $api_url );

/**
 * Filter allows you to apply additional fields to pass.
 *
 * @since 1.6.8 Introduced.
 *
 * @param array
 */
$fields = apply_filters( 'perfect_checkout_fields_controller', array() );
if ( ! empty( $_REQUEST['n'] ) ) { $fields['n'] = trim( sanitize_text_field( wp_unslash( $_REQUEST['n'] ) ) ); }
if ( ! empty( $_REQUEST['p'] ) ) { $fields['p'] = trim( sanitize_text_field( wp_unslash( $_REQUEST['p'] ) ) ); }
if ( ! empty( $_REQUEST['c'] ) ) { $fields['c'] = trim( sanitize_text_field( wp_unslash( $_REQUEST['c'] ) ) ); }
if ( ! empty( $_REQUEST['pm'] ) ) { $fields['pm'] = trim( sanitize_text_field( wp_unslash( $_REQUEST['pm'] ) ) ); }
if ( ! empty( $_REQUEST['cf'] ) ) { $fields['cf'] = trim( sanitize_text_field( wp_unslash( $_REQUEST['cf'] ) ) ); }

$frame_url = add_query_arg( $fields, $frame_url );

// Allow third parties to apply additional arguments.
$frame_url = add_query_arg( apply_filters( 'perfect_checkout_additional_arguments', array() ), $frame_url );

$shop_page_url = get_permalink( wc_get_page_id( 'shop' ) );
?><!DOCTYPE html>
<html <?php language_attributes(); ?>>
	<head>
		<meta charset="<?php bloginfo( 'charset' ); ?>" />
		<meta name="viewport" content="width=device-width, initial-scale=1.0, maximum-scale=1.0, user-scalable=0" />

		<title><?php echo esc_html( get_bloginfo( 'name', 'display' ) . ' - ' . __( 'Checkout', 'perfect-checkout' ) ); ?></title>

		<link rel="icon" href="<?php echo esc_url( untrailingslashit( plugins_url( '/', PERFECTCHECKOUT_FILE ) ) . '/assets/images/fav/android-chrome-192x192.png' ); ?>" sizes="192x192" />
		<link rel="apple-touch-icon" sizes="180x180" href="<?php echo esc_url( untrailingslashit( plugins_url( '/', PERFECTCHECKOUT_FILE ) ) . '/assets/images/fav/apple-touch-icon.png' ); ?>">
		<link rel="icon" type="image/png" sizes="32x32" href="<?php echo esc_url( untrailingslashit( plugins_url( '/', PERFECTCHECKOUT_FILE ) ) . '/assets/images/fav/favicon-32x32.png' ); ?>">
		<link rel="icon" type="image/png" sizes="16x16" href="<?php echo esc_url( untrailingslashit( plugins_url( '/', PERFECTCHECKOUT_FILE ) ) . '/assets/images/fav/favicon-16x16.png' ); ?>">
		<meta name="msapplication-TileImage" content="<?php echo esc_url( untrailingslashit( plugins_url( '/', PERFECTCHECKOUT_FILE ) ) . '/assets/images/fav/apple-touch-icon.png' ); ?>" />

		<script type="text/javascript">
			window.addEventListener('message', function(event) {
				if (event.data && event.data.message) {
					console.log('message: ' + event.data.message);
					if (event.data.message === "back") {
						window.location.href = '<?php echo esc_url( $shop_page_url ); ?>';
					}
					else if (event.data.message === "logout") {
						window.location.href = '<?php echo add_query_arg( 'pc-logout', 1, pc_get_checkout_url() ); ?>';
					}
					else if (event.data.message.startsWith("login")) {
						const credentials = event.data.message.slice(6);
						window.location.href = `<?php echo pc_get_checkout_url(); ?>?pc-login=${credentials}`;
					}
				}
			});
		</script>

		<?php if ( ! empty( $ga_tracking_id ) ) { ?>
		<!-- Global site tag (gtag.js) - Google Analytics -->
		<script async src="https://www.googletagmanager.com/gtag/js?id=<?php echo $ga_tracking_id; ?>"></script>
		<script>
		window.dataLayer = window.dataLayer || [];
		function gtag(){dataLayer.push(arguments);}
		gtag('js', new Date());

		gtag('config', '<?php echo $ga_tracking_id; ?>');
		</script>
		<?php } ?>
	</head>

	<body>
		<div style="min-height: 100vh; display: flex; flex-direction: column; position: fixed; width: 100%; top: 0; left: 0;">
			<iframe id="perfect-frame" class="skip-lazy" src='<?php echo esc_url( $frame_url ); ?>' title='Perfect Checkout Window' referrerpolicy="origin" width="100%" allow="payment *"
				style="flex: 1 0 auto; outline: none; border: none; height: 100%; height: -webkit-fill-available; overflow: hidden; overscroll-behavior: none !important; -webkit-overflow-scrolling: none !important;">	  
			</iframe>
		</div>

	</body>
</html>
