<?php
/**
 * Pay for order form displayed after a customer has clicked the "Change Payment method" button
 * next to a subscription on their My Account page.
 *
 * @author  Perfect Checkout
 * @package Perfect Checkout\Templates
 * @version 1.6.3
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}
?>
<form id="order_review" method="post">

	<table class="shop_table">
		<thead>
			<tr>
				<th class="product-name"><?php echo esc_html_x( 'Product', 'table headings in notification email', 'perfect-checkout' ); ?></th>
				<th class="product-quantity"><?php echo esc_html_x( 'Quantity', 'table headings in notification email', 'perfect-checkout' ); ?></th>
				<th class="product-total"><?php echo esc_html_x( 'Totals', 'table headings in notification email', 'perfect-checkout' ); ?></th>
			</tr>
		</thead>
		<tfoot>
		<?php foreach ( $subscription->get_order_item_totals() as $total ) : ?>
			<tr>
				<th scope="row" colspan="2"><?php echo esc_html( $total['label'] ); ?></th>
				<td class="product-total"><?php echo wp_kses_post( $total['value'] ); ?></td>
			</tr>
		<?php endforeach; ?>
		</tfoot>
		<tbody>
		<?php foreach ( $subscription->get_items() as $item ) : ?>
			<tr>
				<td class="product-name"><?php echo esc_html( $item['name'] ); ?></td>
				<td class="product-quantity"><?php echo esc_html( $item['qty'] ); ?></td>
				<td class="product-subtotal"><?php echo wp_kses_post( $subscription->get_formatted_line_subtotal( $item ) ); ?></td>
			</tr>
		<?php endforeach; ?>
		</tbody>
	</table>

	<div id="payment">
		<?php
		$customer_subscription_ids = WCS_Customer_Store::instance()->get_users_subscription_ids( $subscription->get_customer_id() );
		$available_gateways        = WC()->payment_gateways->get_available_payment_gateways();

		if ( ! $available_gateways ) :
			?>
			<div class="woocommerce-error">
				<p><?php echo esc_html( apply_filters( 'woocommerce_no_available_payment_methods_message', __( 'Sorry, it seems no payment gateways support changing the recurring payment method. Please contact us if you require assistance or to make alternate arrangements.', 'perfect-checkout' ) ) ); ?></p>
			</div>
		<?php endif; ?>

		<?php
		if ( $available_gateways ) :
			$pc_license = get_option( 'perfectcheckout_license' );

			// API URL.
			$api_url = PerfectCheckout::get_api_url() . '/update-subscription';

			// Passes arguments for iFrame.
			$frame_url = add_query_arg( array(
				'pc_version'       => PERFECTCHECKOUT_VERSION,
				'lang'             => get_locale(),
				'text_dir'         => function_exists( 'is_rtl' ) && is_rtl() ? 'rtl' : 'ltr',
				'id'               => $pc_license, // Perfect Checkout account ID.
				'url'              => get_site_url(), // Site URL.
				'ck'               => $subscription->get_customer_id(), // Cart key is the logged in customer.
				'subscription_id'  => $subscription->get_id(), // Subscription ID.
				'subscription_ids' => implode( ',', $customer_subscription_ids ), // All customer subscriptions.
			), $api_url );
			?>
			<iframe class="skip-lazy" src='<?php echo esc_url( $frame_url ); ?>' title='Perfect Checkout Window' referrerpolicy="origin" id="perfect-frame" width="100%" height="400px" allow="payment *"
				style="flex: 1 0 auto; outline: none; border: none; height: -webkit-fill-available; overflow: hidden; overscroll-behavior: none !important; -webkit-overflow-scrolling: none !important;">
			</iframe>
		<?php endif; ?>

	</div>

</form>
